@@ -90,9 +90,6 @@
 #define SSL_EXPERIMENTAL_ENGINE
 #endif
 #endif
-#ifndef SSL_EXPERIMENTAL_SHMCB_IGNORE
-#define SSL_EXPERIMENTAL_SHMCB
-#endif
 #endif /* SSL_EXPERIMENTAL */
 
 /*
@@ -291,7 +288,8 @@
      __FreeBSD_version >= 300000) ||\
     (defined(LINUX) && defined(__GLIBC__) && defined(__GLIBC_MINOR__) &&\
      LINUX >= 2 && __GLIBC__ >= 2 && __GLIBC_MINOR__ >= 1) ||\
-    defined(SOLARIS2) || defined(__hpux)
+    defined(SOLARIS2) || defined(__hpux) ||\
+    (defined (__digital__) && defined (__unix__))
 #define SSL_CAN_USE_SEM
 #define SSL_HAVE_IPCSEM
 #include <sys/types.h>
@@ -487,10 +485,8 @@ typedef enum {
     SSL_SCMODE_UNSET = UNSET,
     SSL_SCMODE_NONE  = 0,
     SSL_SCMODE_DBM   = 1,
-    SSL_SCMODE_SHMHT = 2
-#ifdef SSL_EXPERIMENTAL_SHMCB
-   ,SSL_SCMODE_SHMCB = 3
-#endif
+    SSL_SCMODE_SHMHT = 2,
+    SSL_SCMODE_SHMCB = 3
 } ssl_scmode_t;
 
 /*
@@ -754,7 +750,6 @@ SSL_SESSION *ssl_scache_shmht_retrieve(server_rec *, UCHAR *, int);
 void         ssl_scache_shmht_remove(server_rec *, UCHAR *, int);
 void         ssl_scache_shmht_expire(server_rec *);
 void         ssl_scache_shmht_status(server_rec *, pool *, void (*)(char *, void *), void *);
-#ifdef SSL_EXPERIMENTAL_SHMCB
 void         ssl_scache_shmcb_init(server_rec *, pool *);
 void         ssl_scache_shmcb_kill(server_rec *);
 BOOL         ssl_scache_shmcb_store(server_rec *, UCHAR *, int, time_t, SSL_SESSION *);
@@ -762,7 +757,6 @@ SSL_SESSION *ssl_scache_shmcb_retrieve(server_rec *, UCHAR *, int);
 void         ssl_scache_shmcb_remove(server_rec *, UCHAR *, int);
 void         ssl_scache_shmcb_expire(server_rec *);
 void         ssl_scache_shmcb_status(server_rec *, pool *, void (*)(char *, void *), void *);
-#endif
 
 /*  Pass Phrase Support  */
 void         ssl_pphrase_Handle(server_rec *, pool *);
